[Fusionforge-commits] r11832 - trunk/src/plugins/wiki/www/lib/plugin

Marc-Etienne VARGENAU vargenau at libremir.placard.fr.eu.org
Sat Dec 18 12:12:50 CET 2010


Author: vargenau
Date: 2010-12-18 12:12:50 +0100 (Sat, 18 Dec 2010)
New Revision: 11832

Modified:
   trunk/src/plugins/wiki/www/lib/plugin/PageDump.php
Log:
CVS --> Subversion

Modified: trunk/src/plugins/wiki/www/lib/plugin/PageDump.php
===================================================================
--- trunk/src/plugins/wiki/www/lib/plugin/PageDump.php	2010-12-18 11:09:28 UTC (rev 11831)
+++ trunk/src/plugins/wiki/www/lib/plugin/PageDump.php	2010-12-18 11:12:50 UTC (rev 11832)
@@ -1,5 +1,5 @@
 <?php // -*-php-*-
-// rcs_id('$Id: PageDump.php 7638 2010-08-11 11:58:40Z vargenau $');
+// rcs_id('$Id: PageDump.php 7780 2010-12-16 12:52:11Z vargenau $');
 /*
  * Copyright (C) 2003 $ThePhpWikiProgrammingTeam
  *
@@ -22,7 +22,7 @@
 
 /**
  * PhpWikiPlugin for PhpWiki developers to generate single page dumps
  * for checking into cvs, or for users or the admin to produce a
  * downloadable page dump of a single page.
  *
  * This plugin will also be useful to (semi-)automatically sync pages
@@ -36,7 +36,7 @@
  *
  * Usage:
  *  Direct URL access:
- *   http://...phpwiki/PageDump?page=HomePage?format=forcvs
+ *   http://...phpwiki/PageDump?page=HomePage?format=forsvn
  *   http://...phpwiki/index.php?PageDump&page=HomePage
  *   http://...phpwiki/index.php?PageDump&page=HomePage&download=1
  *  Static:
@@ -63,7 +63,7 @@
         return array('s'    => false,
                      'page' => '[pagename]',
                      //'encoding' => 'binary', // 'binary', 'quoted-printable'
-                     'format' => false, // 'normal', 'forcvs', 'backup'
+                     'format' => false, // 'normal', 'forsvn', 'forcvs', 'backup'
                      // display within WikiPage or give a downloadable
                      // raw pgsrc?
                      'download' => false);
@@ -91,7 +91,7 @@
         $mailified = MailifyPage($p, ($format == 'backup') ? 99 : 1);
 
         // fixup_headers massages the page dump headers depending on
         // the 'format' argument, 'normal'(default) or 'forcvs'.
         //
         // Normal: Don't add X-Rcs-Id, add unique Message-Id, don't
         // strip any fields from Content-Type.
@@ -102,8 +102,8 @@
 
         $this->pagename = $page;
         $this->generateMessageId($mailified);
-        if ($format == 'forcvs')
-            $this->fixup_headers_forcvs($mailified);
+        if (($format == 'forsvn') || ($format == 'forcvs'))
+            $this->fixup_headers_forsvn($mailified);
         else // backup or normal
             $this->fixup_headers($mailified);
 
@@ -142,11 +142,11 @@
         // text if it is too long--unless quoted-printable (TODO).
         $mailified = wordwrap($mailified, 70);
 
-        $dlcvs = Button(array(//'page' => $page,
+        $dlsvn = Button(array(//'page' => $page,
                               'action' => $this->getName(),
-                              'format'=> 'forcvs',
+                              'format'=> 'forsvn',
                               'download'=> true),
-                        _("Download for CVS"),
+                        _("Download for Subversion"),
                         $page);
         $dl = Button(array(//'page' => $page,
                            'action' => $this->getName(),
@@ -166,7 +166,7 @@
         if (!$Sep = $WikiTheme->getButtonSeparator())
             $Sep = " ";
 
-        if ($format == 'forcvs') {
+        if ($format == 'forsvn') {
             $desc = _("(formatted for PhpWiki developers as pgsrc template, not for backing up)");
             $altpreviewbuttons = HTML(
                                       Button(array('action' => $this->getName()),
@@ -183,7 +183,7 @@
             $desc = _("(formatted for backing up: all revisions)"); // all revisions
             $altpreviewbuttons = HTML(
                                       Button(array('action' => $this->getName(),
-                                                   'format'=> 'forcvs'),
+                                                   'format'=> 'forsvn'),
                                              _("Preview as developer format"),
                                              $page),
                                       $Sep,
@@ -196,7 +196,7 @@
             $desc = _("(normal formatting: latest revision only)");
             $altpreviewbuttons = HTML(
                                       Button(array('action' => $this->getName(),
-                                                   'format'=> 'forcvs'),
+                                                   'format'=> 'forsvn'),
                                              _("Preview as developer format"),
                                              $page),
                                       $Sep,
@@ -212,7 +212,7 @@
 _("The wordwrap of the preview doesn't take nested markup or list indentation into consideration!")
 . " ",
 HTML::em(
-_("PhpWiki developers should manually inspect the downloaded file for nested markup before rewrapping with emacs and checking into CVS.")
+_("PhpWiki developers should manually inspect the downloaded file for nested markup before rewrapping with emacs and checking into Subversion.")
          )
                         );
 
@@ -222,7 +222,7 @@
                     HTML::div(array('class' => 'errors'),
                               HTML::strong(_("Warning:")),
                               " ", $warning),
-                    $dl, $Sep, $dlall, $Sep, $dlcvs
+                    $dl, $Sep, $dlall, $Sep, $dlsvn
                     );
     }
 
@@ -269,10 +269,10 @@
         $mailified = implode("\n", array_values($return));
     }
 
-    function fixup_headers_forcvs(&$mailified) {
+    function fixup_headers_forsvn(&$mailified) {
         $array = explode("\n", $mailified);
 
         // Massage headers to prepare for developer checkin to CVS.
         $item_to_insert = "X-Rcs-Id: \$Id\$";
         $insert_into_key_position = 2;
         $returnval_ignored = array_splice($array,
@@ -22,7 +22,7 @@
 /**
  * PhpWikiPlugin for PhpWiki developers to generate single page dumps
- * for checking into cvs, or for users or the admin to produce a
+ * for checking into Subversion, or for users or the admin to produce a
  * downloadable page dump of a single page.
  *
@@ -91,7 +91,7 @@
 
         // fixup_headers massages the page dump headers depending on
-        // the 'format' argument, 'normal'(default) or 'forcvs'.
+        // the 'format' argument, 'normal'(default) or 'forsvn'.
         //
         // Normal: Don't add X-Rcs-Id, add unique Message-Id, don't
@@ -269,10 +269,10 @@
         $array = explode("\n", $mailified);
 
-        // Massage headers to prepare for developer checkin to CVS.
+        // Massage headers to prepare for developer checkin to Subversion.
         $item_to_insert = "X-Rcs-Id: \$Id\$";
         $insert_into_key_position = 2;




More information about the Fusionforge-commits mailing list